@@ -5,23 +5,19 @@ use strict;
 
 =head1 NAME
 
-MooseX::Role::ConstructorRoleApplication - apply roles during construction
+MooseX::Role::ConstructorRoleApplication - apply roles right after construction
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
-
-Perhaps a little code snippet.
-
     package Foo;
     use Moose;
     with 'MooseX::Role::ConstructorRoleApplication';
@@ -39,6 +35,29 @@ new instance.
 It does not apply the roles to the class itself, so other instances
 may be constructed I<without> the roles.
 
+This role is similar in purpose to L<MooseX::Traits> but composes roles into
+the class instance immediately after construction, rather than creating an
+anonymous class before the new object is instantiated.
+
+The advantage of this module over
+C<MooseX::Traits> module is that role application is accomplished with a
+single call to C<new>.  Use C<MooseX::Role::ConstructorRoleApplication> if
+you're a fan of L<Test::More>'s C<new_ok> or for other reasons require a
+single call to C<new> rather than a chain of calls (as would be necessary
+with C<MooseX::Traits>).  Otherwise, use C<MooseX::Traits>.
+
+   # using MooseX::Role::ConstructorRoleApplication
+   my $obj = Class->new(apply=>['Role']);
+
+   # using MooseX::Traits
+   my $obj = Class->with_traits('Role')->new;
+
+Of course, when using C<MooseX::Role::ConstructorRoleApplication>, you
+cannot supply to the constructor values for attributes provided by the
+role (or roles) that are yet to be applied.  Such values must be set
+after the object is instantiated.  Some mechanism to set role attributes
+may exist in a future version.
+
 =cut
 
 use Moose::Role;
@@ -104,6 +123,13 @@ L<http://search.cpan.org/dist/MooseX-Role-ConstructorRoleApplication/>
 =back
 
 
+=head1 SEE ALSO
+
+L<MooseX::Traits> is a module similar in purpose that performs role
+performs role composition prior to, rather than after, instantiation.
+In most cases, a better choice than this module.
+
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2011 Benon Technologies Pty Ltd
